#!/bin/sh
emacs_major_version=21
emacs_minor_version=1
emacs_beta_version=12
xemacs_codename="Channel Islands"
infodock_major_version=4
infodock_minor_version=0
infodock_build_version=7
